@@ -1,6 +1,6 @@
 use 5.38.0;
 use experimental 'class';
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 class Game::Snake {
 	use Raylib::App;	
 	use Raylib::FFI;
@@ -25,6 +25,7 @@ class Game::Snake {
 	field $game_over = 0;
 	field $score = 0;
 	field $last_score = 10;
+	field $high_score = 0;
 	field @snake;
 	field $food;
 	field $fps = 2;
@@ -32,6 +33,7 @@ class Game::Snake {
 	method reset_game () {
 		$game_over = 0;
 		$score = 0;
+		$last_score = 10;
 		$fps = 2;
 		@snake = ();
 		push @snake, Game::Snake::Head->new(
@@ -92,7 +94,13 @@ class Game::Snake {
 					if ($game_over) {
 						$self->reset_game();
 					}
+				},
+				KEY_SPACE() => sub { 
+					if ($game_over) {
+						$self->reset_game();
+					}
 				}
+
 			},
 		);
 
@@ -104,7 +112,7 @@ class Game::Snake {
 					$frame++;
 					$app->fps($fps);
 					$app->clear();
-					$score_text->draw("Score: $score");
+					$score_text->draw("Score: $score High Score: $high_score");
 
 					$keyboard->handle_events();
 					if ($game_over) {
@@ -241,6 +249,9 @@ class Game::Snake {
 		
 		if ($collide{$food->x}->{$food->y}) {
 			$score += $food_score;
+			if ($score > $high_score) {
+				$high_score = $score;
+			}	
 			$food = undef;
 			$self->extend_snake;
 			return;
@@ -262,7 +273,7 @@ Game::Snake - A clone of the classic snake game using raylib
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
